/**
 * Copyright (c) 2025 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#pragma once
#include "duskraylib.h"
#include "display/renderbase.h"

extern uint8_t RENDER_BACKGROUND_X;
extern uint8_t RENDER_BACKGROUND_Y;
extern bool_t RENDER_DISPLAY_ON;
extern uint8_t RENDER_TILES[RENDER_TILE_COUNT];
extern Color RENDER_PALETTE[RENDER_PALETTE_COLOR_COUNT];

/**
 * Sets the background tile data.
 * 
 * @param index The starting index of the tile data.
 * @param count The number of tiles to set.
 * @param tiles Pointer to the tile data array.
 */
void renderTilesBuffer(
  const uint8_t index,
  const uint8_t count,
  const uint8_t *tiles
);

/**
 * Sets the background tiles.
 * 
 * @param x The x-coordinate of the top-left corner of the background.
 * @param y The y-coordinate of the top-left corner of the background.
 * @param width The width of the background in tiles.
 * @param height The height of the background in tiles.
 * @param tiles Pointer to the tile map data.
 */
void renderBackgroundTilesBufferRectangle(
  const uint8_t x,
  const uint8_t y,
  const uint8_t width,
  const uint8_t height,
  const uint8_t *tiles
);